@@ -74,7 +74,9 @@ class QueryParamsMixin:
     """
 
     required_query_keys = []
+
     required_multivalue = []
+    optional_multivalue = []
 
     def get_queryparams(self):
         missing_keys = set()
@@ -82,14 +84,17 @@ class QueryParamsMixin:
         queryparams = self.event.get("queryStringParameters") or {}
         multivalue_queryparams = self.event.get("multiValueQueryStringParameters") or {}
 
-        result = {**queryparams, **multivalue_queryparams}
+        result = queryparams
 
         for key in self.required_query_keys:
-            if key not in queryparams:
+            if key in queryparams:
+                result[key] = queryparams[key]
+            else:
                 missing_keys.add(key)
-
         for key in self.required_multivalue:
-            if key not in multivalue_queryparams:
+            if key in multivalue_queryparams:
+                result[key] = multivalue_queryparams[key]
+            else:
                 missing_keys.add(key)
 
         if missing_keys:
@@ -97,6 +102,11 @@ class QueryParamsMixin:
             self.error = (message, 400)
             raise BadRequest(message=message)
 
+        # Collect all optional keys and values.
+        for key in self.optional_multivalue:
+            if key in multivalue_queryparams:
+                result[key] = multivalue_queryparams[key]
+
         return result
 
 
